@@ -6,7 +6,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LGPL-3.0-only
 */
 
 use cardano_ouroboros_network::{
-    mux::tcp::Channel,
+    mux::connection::Channel,
     protocols::{
         handshake,
         pingpong,
@@ -15,6 +15,8 @@ use cardano_ouroboros_network::{
 use std::net::{TcpListener, TcpStream};
 use log::{info, error};
 use futures::executor::block_on;
+use cardano_ouroboros_network::protocols::handshake::ConnectionType;
+use cardano_ouroboros_network::mux::connection::Stream::Tcp;
 
 mod common;
 
@@ -31,11 +33,11 @@ fn main() {
 }
 
 fn handle(stream: TcpStream, cfg: &common::Config) -> Result<(), String> {
-    let channel = Channel::new(stream);
+    let channel = Channel::new(Tcp(stream));
 
     info!("new client!");
     block_on(async {
-        channel.execute(handshake::HandshakeProtocol::expect(cfg.magic)).await?;
+        channel.execute(handshake::HandshakeProtocol::expect(cfg.magic, ConnectionType::Tcp)).await?;
         channel.execute(pingpong::PingPongProtocol::expect(0x0100)).await?;
         Ok(())
     })
